==> img0ch-2.1.18.zip: img0ch/_template/zeromin2/migrate_load.cs <==
<?cs include:"zeromin2/header.cs" ?>

<?cs include:"zeromin2/menu.cs" ?>

<?cs include:"zeromin2/log_side_menu.cs" ?>

<div id="main">

<form id="migrateContainerForm" action="<?cs var:html_escape(ZerominScript) ?>" method="post">

<div id="navhead">
  <hr />
  <a href="<?cs var:html_escape(ZerominScript) ?>?class=bbs&amp;method=load&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">掲示板管理</a>
  &gt;
  <a href="<?cs var:html_escape(ZerominScript) ?>?class=system&amp;method=load&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">システム</a>
  &gt;
  <a href="<?cs var:html_escape(ZerominScript) ?>?class=migrate&amp;method=load&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">旧版のデータの移植</a>
</div>

<h1>旧版のデータの移植</h1>

<?cs if:Code0 ?>
<?cs if:Done_migrate_save ?><div class="noticeSuccess" id="notify"><p>選択されたデータを移植しました</p></div><?cs /if ?>
<?cs else ?>
<?cs if:Code1 ?><div class="noticeFailed" id="notify"><p>実行権限がありません</p></div><?cs /if ?>
<?cs /if ?>

<p>
  過去のデータ(2005/12/30以前)を現行版のデータに移行します。<br />
  管理権限を持つグループに所属するユーザーのみ実行可能です。
</p>

<div class="noListStyle">
 <ul>
  <li><input id="archive" type="checkbox" name="archive" value="1" />&nbsp;<label for="archive">過去ログ</label></li>
  <li><input id="pool" type="checkbox" name="pool" value="1" />&nbsp;<label for="pool">プールスレッド</label></li>
  <li><input id="banner" type="checkbox" name="banner" value="1" />&nbsp;<label for="banner">バナー</label></li>
  <li><input id="category" type="checkbox" name="category" value="1" />&nbsp;<label for="category">カテゴリ</label></li>
  <li><input id="user" type="checkbox" name="user" value="1" />&nbsp;<label for="user">ユーザー</label></li>
  <li><input id="cap" type="checkbox" name="cap" value="1" />&nbsp;<label for="cap">キャップ</label></li>
  <li><input id="hostlog" type="checkbox" name="hostlog" value="1" />&nbsp;<label for="hostlog">ホストログ</label></li>
  <li><input id="threadlog" type="checkbox" name="threadlog" value="1" />&nbsp;<label for="threadlog">スレッド作成ログ</label></li>
 </ul>
 <input type="submit" value="実行" />
</div>

<div class="formFooter">
<input type="hidden" name="<?cs var:html_escape(SessionName) ?>" value="<?cs var:html_escape(Session) ?>" />
<input type="hidden" name="token" value="<?cs var:html_escape(Token) ?>" />
<input type="hidden" name="class" value="migrate" />
<input type="hidden" name="method" value="save" />
<input type="hidden" name="OK" value="load" />
<input type="hidden" name="NG" value="load" />
<br id="endmain" />
</div>

</form>

</div>

<?cs include:"zeromin2/footer.cs" ?>

==> img0ch-3.1.7.zip: img0ch/_template/zeromin2/migrate_load.cs <==
<?cs include:"zeromin2/header.cs" ?>

<?cs include:"zeromin2/menu.cs" ?>

<?cs include:"zeromin2/log_side_menu.cs" ?>

<div id="main">

<form id="migrateContainerForm" action="<?cs var:html_escape(ZerominScript) ?>" method="post">

<div id="navhead">
  <hr />
  <a href="<?cs var:html_escape(ZerominScript) ?>?class=bbs&amp;method=load&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">掲示板管理</a>
  &gt;
  <a href="<?cs var:html_escape(ZerominScript) ?>?class=system&amp;method=load&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">システム</a>
  &gt;
  <a href="<?cs var:html_escape(ZerominScript) ?>?class=migrate&amp;method=load&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">旧版のデータの移植</a>
</div>

<h1>旧版のデータの移植</h1>

<?cs if:Code0 ?>
<?cs if:Done_migrate_save ?><div class="noticeSuccess" id="notify"><p>選択されたデータを移植しました</p></div><?cs /if ?>
<?cs else ?>
<?cs if:Code1 ?><div class="noticeFailed" id="notify"><p>実行権限がありません</p></div><?cs /if ?>
<?cs /if ?>

<p>
  全掲示板を対象に過去のデータ(2005/12/30以前)を現行版のデータに移行します。<br />
  管理権限を持つグループに所属するユーザーのみ実行可能です。<br />
<!--
  UTF8版0chの掲示板から移行する場合は「UTF-8としてインポート」にチェックを入れてください。
-->
</p>

<div class="noListStyle">
 <ul>
  <li><input id="archive" type="checkbox" name="archive" value="1" />&nbsp;<label for="archive">過去ログ</label></li>
  <li><input id="pool" type="checkbox" name="pool" value="1" />&nbsp;<label for="pool">プールスレッド</label></li>
  <li><input id="banner" type="checkbox" name="banner" value="1" />&nbsp;<label for="banner">バナー</label></li>
  <li><input id="category" type="checkbox" name="category" value="1" />&nbsp;<label for="category">カテゴリ</label></li>
  <li><input id="user" type="checkbox" name="user" value="1" />&nbsp;<label for="user">ユーザー</label></li>
  <li><input id="cap" type="checkbox" name="cap" value="1" />&nbsp;<label for="cap">キャップ</label></li>
  <li><input id="hostlog" type="checkbox" name="hostlog" value="1" />&nbsp;<label for="hostlog">ホストログ</label></li>
  <li><input id="threadlog" type="checkbox" name="threadlog" value="1" />&nbsp;<label for="threadlog">スレッド作成ログ</label></li>
 </ul>
<!--
 <input id="utf8" type="checkbox" name="utf8" value="1" />&nbsp;<label for="utf8">UTF-8としてインポート (キャップ及びバナーのみ対象)</label>
-->
 <input type="submit" value="実行" />
</div>

<div class="formFooter">
<input type="hidden" name="<?cs var:html_escape(SessionName) ?>" value="<?cs var:html_escape(Session) ?>" />
<input type="hidden" name="token" value="<?cs var:html_escape(Token) ?>" />
<input type="hidden" name="class" value="migrate" />
<input type="hidden" name="method" value="save" />
<input type="hidden" name="OK" value="load" />
<input type="hidden" name="NG" value="load" />
<br id="endmain" />
</div>

</form>

</div>

<?cs include:"zeromin2/footer.cs" ?>
